from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from curia.api.swagger_client.api.internal_api import InternalApi
from curia.api.swagger_client.api.platform_api import PlatformApi



# coding: utf-8

"""
    Curia Platform API

    These are the docs for the curia platform API. To test, generate an authorization token first.  # noqa: E501

    OpenAPI spec version: 1.18.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class CohortWindow(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'patient_metadata_start_filter_enabled': 'bool',
        'patient_metadata_end_filter_enabled': 'bool',
        'cohort_logic': 'str',
        'cohort_display_logic': 'str',
        'outcome_logic': 'str',
        'intervention_logic': 'str',
        'period_definitions': 'list[PeriodDefinition]',
        'outcome_type': 'str',
        'aggregation_type': 'str',
        'aggregation_column': 'str',
        'cohort_filters': 'list[CohortFilter]',
        'outcome_aggregated_value': 'float',
        'outcome_list_query': 'str',
        'outcome_count_query': 'str',
        'intervention_list_query': 'str',
        'intervention_count_query': 'str',
        'cohort_list_query': 'str',
        'cohort_count_query': 'str',
        'outcome_count': 'float',
        'intervention_count': 'float',
        'cohort_count': 'float',
        'geographic_counts': 'GeographicCounts',
        'geographic_queries': 'GeographicQueries',
        'dataset_ids': 'list[str]'
    }

    attribute_map = {
        'patient_metadata_start_filter_enabled': 'patientMetadataStartFilterEnabled',
        'patient_metadata_end_filter_enabled': 'patientMetadataEndFilterEnabled',
        'cohort_logic': 'cohortLogic',
        'cohort_display_logic': 'cohortDisplayLogic',
        'outcome_logic': 'outcomeLogic',
        'intervention_logic': 'interventionLogic',
        'period_definitions': 'periodDefinitions',
        'outcome_type': 'outcomeType',
        'aggregation_type': 'aggregationType',
        'aggregation_column': 'aggregationColumn',
        'cohort_filters': 'cohortFilters',
        'outcome_aggregated_value': 'outcomeAggregatedValue',
        'outcome_list_query': 'outcomeListQuery',
        'outcome_count_query': 'outcomeCountQuery',
        'intervention_list_query': 'interventionListQuery',
        'intervention_count_query': 'interventionCountQuery',
        'cohort_list_query': 'cohortListQuery',
        'cohort_count_query': 'cohortCountQuery',
        'outcome_count': 'outcomeCount',
        'intervention_count': 'interventionCount',
        'cohort_count': 'cohortCount',
        'geographic_counts': 'geographicCounts',
        'geographic_queries': 'geographicQueries',
        'dataset_ids': 'datasetIds'
    }

    def __init__(self, patient_metadata_start_filter_enabled=None, patient_metadata_end_filter_enabled=None, cohort_logic=None, cohort_display_logic=None, outcome_logic=None, intervention_logic=None, period_definitions=None, outcome_type=None, aggregation_type=None, aggregation_column=None, cohort_filters=None, outcome_aggregated_value=None, outcome_list_query=None, outcome_count_query=None, intervention_list_query=None, intervention_count_query=None, cohort_list_query=None, cohort_count_query=None, outcome_count=None, intervention_count=None, cohort_count=None, geographic_counts=None, geographic_queries=None, dataset_ids=None):  # noqa: E501
        """CohortWindow - a model defined in Swagger"""  # noqa: E501
        self._patient_metadata_start_filter_enabled = None
        self._patient_metadata_end_filter_enabled = None
        self._cohort_logic = None
        self._cohort_display_logic = None
        self._outcome_logic = None
        self._intervention_logic = None
        self._period_definitions = None
        self._outcome_type = None
        self._aggregation_type = None
        self._aggregation_column = None
        self._cohort_filters = None
        self._outcome_aggregated_value = None
        self._outcome_list_query = None
        self._outcome_count_query = None
        self._intervention_list_query = None
        self._intervention_count_query = None
        self._cohort_list_query = None
        self._cohort_count_query = None
        self._outcome_count = None
        self._intervention_count = None
        self._cohort_count = None
        self._geographic_counts = None
        self._geographic_queries = None
        self._dataset_ids = None
        self.discriminator = None
        if patient_metadata_start_filter_enabled is not None:
            self.patient_metadata_start_filter_enabled = patient_metadata_start_filter_enabled
        if patient_metadata_end_filter_enabled is not None:
            self.patient_metadata_end_filter_enabled = patient_metadata_end_filter_enabled
        if cohort_logic is not None:
            self.cohort_logic = cohort_logic
        if cohort_display_logic is not None:
            self.cohort_display_logic = cohort_display_logic
        if outcome_logic is not None:
            self.outcome_logic = outcome_logic
        if intervention_logic is not None:
            self.intervention_logic = intervention_logic
        if period_definitions is not None:
            self.period_definitions = period_definitions
        if outcome_type is not None:
            self.outcome_type = outcome_type
        if aggregation_type is not None:
            self.aggregation_type = aggregation_type
        if aggregation_column is not None:
            self.aggregation_column = aggregation_column
        if cohort_filters is not None:
            self.cohort_filters = cohort_filters
        if outcome_aggregated_value is not None:
            self.outcome_aggregated_value = outcome_aggregated_value
        if outcome_list_query is not None:
            self.outcome_list_query = outcome_list_query
        if outcome_count_query is not None:
            self.outcome_count_query = outcome_count_query
        if intervention_list_query is not None:
            self.intervention_list_query = intervention_list_query
        if intervention_count_query is not None:
            self.intervention_count_query = intervention_count_query
        if cohort_list_query is not None:
            self.cohort_list_query = cohort_list_query
        if cohort_count_query is not None:
            self.cohort_count_query = cohort_count_query
        if outcome_count is not None:
            self.outcome_count = outcome_count
        if intervention_count is not None:
            self.intervention_count = intervention_count
        if cohort_count is not None:
            self.cohort_count = cohort_count
        if geographic_counts is not None:
            self.geographic_counts = geographic_counts
        if geographic_queries is not None:
            self.geographic_queries = geographic_queries
        if dataset_ids is not None:
            self.dataset_ids = dataset_ids

    @property
    def patient_metadata_start_filter_enabled(self):
        """Gets the patient_metadata_start_filter_enabled of this CohortWindow.  # noqa: E501


        :return: The patient_metadata_start_filter_enabled of this CohortWindow.  # noqa: E501
        :rtype: bool
        """
        return self._patient_metadata_start_filter_enabled

    @patient_metadata_start_filter_enabled.setter
    def patient_metadata_start_filter_enabled(self, patient_metadata_start_filter_enabled):
        """Sets the patient_metadata_start_filter_enabled of this CohortWindow.


        :param patient_metadata_start_filter_enabled: The patient_metadata_start_filter_enabled of this CohortWindow.  # noqa: E501
        :type: bool
        """

        self._patient_metadata_start_filter_enabled = patient_metadata_start_filter_enabled

    @property
    def patient_metadata_end_filter_enabled(self):
        """Gets the patient_metadata_end_filter_enabled of this CohortWindow.  # noqa: E501


        :return: The patient_metadata_end_filter_enabled of this CohortWindow.  # noqa: E501
        :rtype: bool
        """
        return self._patient_metadata_end_filter_enabled

    @patient_metadata_end_filter_enabled.setter
    def patient_metadata_end_filter_enabled(self, patient_metadata_end_filter_enabled):
        """Sets the patient_metadata_end_filter_enabled of this CohortWindow.


        :param patient_metadata_end_filter_enabled: The patient_metadata_end_filter_enabled of this CohortWindow.  # noqa: E501
        :type: bool
        """

        self._patient_metadata_end_filter_enabled = patient_metadata_end_filter_enabled

    @property
    def cohort_logic(self):
        """Gets the cohort_logic of this CohortWindow.  # noqa: E501


        :return: The cohort_logic of this CohortWindow.  # noqa: E501
        :rtype: str
        """
        return self._cohort_logic

    @cohort_logic.setter
    def cohort_logic(self, cohort_logic):
        """Sets the cohort_logic of this CohortWindow.


        :param cohort_logic: The cohort_logic of this CohortWindow.  # noqa: E501
        :type: str
        """

        self._cohort_logic = cohort_logic

    @property
    def cohort_display_logic(self):
        """Gets the cohort_display_logic of this CohortWindow.  # noqa: E501


        :return: The cohort_display_logic of this CohortWindow.  # noqa: E501
        :rtype: str
        """
        return self._cohort_display_logic

    @cohort_display_logic.setter
    def cohort_display_logic(self, cohort_display_logic):
        """Sets the cohort_display_logic of this CohortWindow.


        :param cohort_display_logic: The cohort_display_logic of this CohortWindow.  # noqa: E501
        :type: str
        """

        self._cohort_display_logic = cohort_display_logic

    @property
    def outcome_logic(self):
        """Gets the outcome_logic of this CohortWindow.  # noqa: E501


        :return: The outcome_logic of this CohortWindow.  # noqa: E501
        :rtype: str
        """
        return self._outcome_logic

    @outcome_logic.setter
    def outcome_logic(self, outcome_logic):
        """Sets the outcome_logic of this CohortWindow.


        :param outcome_logic: The outcome_logic of this CohortWindow.  # noqa: E501
        :type: str
        """

        self._outcome_logic = outcome_logic

    @property
    def intervention_logic(self):
        """Gets the intervention_logic of this CohortWindow.  # noqa: E501


        :return: The intervention_logic of this CohortWindow.  # noqa: E501
        :rtype: str
        """
        return self._intervention_logic

    @intervention_logic.setter
    def intervention_logic(self, intervention_logic):
        """Sets the intervention_logic of this CohortWindow.


        :param intervention_logic: The intervention_logic of this CohortWindow.  # noqa: E501
        :type: str
        """

        self._intervention_logic = intervention_logic

    @property
    def period_definitions(self):
        """Gets the period_definitions of this CohortWindow.  # noqa: E501


        :return: The period_definitions of this CohortWindow.  # noqa: E501
        :rtype: list[PeriodDefinition]
        """
        return self._period_definitions

    @period_definitions.setter
    def period_definitions(self, period_definitions):
        """Sets the period_definitions of this CohortWindow.


        :param period_definitions: The period_definitions of this CohortWindow.  # noqa: E501
        :type: list[PeriodDefinition]
        """

        self._period_definitions = period_definitions

    @property
    def outcome_type(self):
        """Gets the outcome_type of this CohortWindow.  # noqa: E501


        :return: The outcome_type of this CohortWindow.  # noqa: E501
        :rtype: str
        """
        return self._outcome_type

    @outcome_type.setter
    def outcome_type(self, outcome_type):
        """Sets the outcome_type of this CohortWindow.


        :param outcome_type: The outcome_type of this CohortWindow.  # noqa: E501
        :type: str
        """

        self._outcome_type = outcome_type

    @property
    def aggregation_type(self):
        """Gets the aggregation_type of this CohortWindow.  # noqa: E501


        :return: The aggregation_type of this CohortWindow.  # noqa: E501
        :rtype: str
        """
        return self._aggregation_type

    @aggregation_type.setter
    def aggregation_type(self, aggregation_type):
        """Sets the aggregation_type of this CohortWindow.


        :param aggregation_type: The aggregation_type of this CohortWindow.  # noqa: E501
        :type: str
        """

        self._aggregation_type = aggregation_type

    @property
    def aggregation_column(self):
        """Gets the aggregation_column of this CohortWindow.  # noqa: E501


        :return: The aggregation_column of this CohortWindow.  # noqa: E501
        :rtype: str
        """
        return self._aggregation_column

    @aggregation_column.setter
    def aggregation_column(self, aggregation_column):
        """Sets the aggregation_column of this CohortWindow.


        :param aggregation_column: The aggregation_column of this CohortWindow.  # noqa: E501
        :type: str
        """

        self._aggregation_column = aggregation_column

    @property
    def cohort_filters(self):
        """Gets the cohort_filters of this CohortWindow.  # noqa: E501


        :return: The cohort_filters of this CohortWindow.  # noqa: E501
        :rtype: list[CohortFilter]
        """
        return self._cohort_filters

    @cohort_filters.setter
    def cohort_filters(self, cohort_filters):
        """Sets the cohort_filters of this CohortWindow.


        :param cohort_filters: The cohort_filters of this CohortWindow.  # noqa: E501
        :type: list[CohortFilter]
        """

        self._cohort_filters = cohort_filters

    @property
    def outcome_aggregated_value(self):
        """Gets the outcome_aggregated_value of this CohortWindow.  # noqa: E501


        :return: The outcome_aggregated_value of this CohortWindow.  # noqa: E501
        :rtype: float
        """
        return self._outcome_aggregated_value

    @outcome_aggregated_value.setter
    def outcome_aggregated_value(self, outcome_aggregated_value):
        """Sets the outcome_aggregated_value of this CohortWindow.


        :param outcome_aggregated_value: The outcome_aggregated_value of this CohortWindow.  # noqa: E501
        :type: float
        """

        self._outcome_aggregated_value = outcome_aggregated_value

    @property
    def outcome_list_query(self):
        """Gets the outcome_list_query of this CohortWindow.  # noqa: E501


        :return: The outcome_list_query of this CohortWindow.  # noqa: E501
        :rtype: str
        """
        return self._outcome_list_query

    @outcome_list_query.setter
    def outcome_list_query(self, outcome_list_query):
        """Sets the outcome_list_query of this CohortWindow.


        :param outcome_list_query: The outcome_list_query of this CohortWindow.  # noqa: E501
        :type: str
        """

        self._outcome_list_query = outcome_list_query

    @property
    def outcome_count_query(self):
        """Gets the outcome_count_query of this CohortWindow.  # noqa: E501


        :return: The outcome_count_query of this CohortWindow.  # noqa: E501
        :rtype: str
        """
        return self._outcome_count_query

    @outcome_count_query.setter
    def outcome_count_query(self, outcome_count_query):
        """Sets the outcome_count_query of this CohortWindow.


        :param outcome_count_query: The outcome_count_query of this CohortWindow.  # noqa: E501
        :type: str
        """

        self._outcome_count_query = outcome_count_query

    @property
    def intervention_list_query(self):
        """Gets the intervention_list_query of this CohortWindow.  # noqa: E501


        :return: The intervention_list_query of this CohortWindow.  # noqa: E501
        :rtype: str
        """
        return self._intervention_list_query

    @intervention_list_query.setter
    def intervention_list_query(self, intervention_list_query):
        """Sets the intervention_list_query of this CohortWindow.


        :param intervention_list_query: The intervention_list_query of this CohortWindow.  # noqa: E501
        :type: str
        """

        self._intervention_list_query = intervention_list_query

    @property
    def intervention_count_query(self):
        """Gets the intervention_count_query of this CohortWindow.  # noqa: E501


        :return: The intervention_count_query of this CohortWindow.  # noqa: E501
        :rtype: str
        """
        return self._intervention_count_query

    @intervention_count_query.setter
    def intervention_count_query(self, intervention_count_query):
        """Sets the intervention_count_query of this CohortWindow.


        :param intervention_count_query: The intervention_count_query of this CohortWindow.  # noqa: E501
        :type: str
        """

        self._intervention_count_query = intervention_count_query

    @property
    def cohort_list_query(self):
        """Gets the cohort_list_query of this CohortWindow.  # noqa: E501


        :return: The cohort_list_query of this CohortWindow.  # noqa: E501
        :rtype: str
        """
        return self._cohort_list_query

    @cohort_list_query.setter
    def cohort_list_query(self, cohort_list_query):
        """Sets the cohort_list_query of this CohortWindow.


        :param cohort_list_query: The cohort_list_query of this CohortWindow.  # noqa: E501
        :type: str
        """

        self._cohort_list_query = cohort_list_query

    @property
    def cohort_count_query(self):
        """Gets the cohort_count_query of this CohortWindow.  # noqa: E501


        :return: The cohort_count_query of this CohortWindow.  # noqa: E501
        :rtype: str
        """
        return self._cohort_count_query

    @cohort_count_query.setter
    def cohort_count_query(self, cohort_count_query):
        """Sets the cohort_count_query of this CohortWindow.


        :param cohort_count_query: The cohort_count_query of this CohortWindow.  # noqa: E501
        :type: str
        """

        self._cohort_count_query = cohort_count_query

    @property
    def outcome_count(self):
        """Gets the outcome_count of this CohortWindow.  # noqa: E501


        :return: The outcome_count of this CohortWindow.  # noqa: E501
        :rtype: float
        """
        return self._outcome_count

    @outcome_count.setter
    def outcome_count(self, outcome_count):
        """Sets the outcome_count of this CohortWindow.


        :param outcome_count: The outcome_count of this CohortWindow.  # noqa: E501
        :type: float
        """

        self._outcome_count = outcome_count

    @property
    def intervention_count(self):
        """Gets the intervention_count of this CohortWindow.  # noqa: E501


        :return: The intervention_count of this CohortWindow.  # noqa: E501
        :rtype: float
        """
        return self._intervention_count

    @intervention_count.setter
    def intervention_count(self, intervention_count):
        """Sets the intervention_count of this CohortWindow.


        :param intervention_count: The intervention_count of this CohortWindow.  # noqa: E501
        :type: float
        """

        self._intervention_count = intervention_count

    @property
    def cohort_count(self):
        """Gets the cohort_count of this CohortWindow.  # noqa: E501


        :return: The cohort_count of this CohortWindow.  # noqa: E501
        :rtype: float
        """
        return self._cohort_count

    @cohort_count.setter
    def cohort_count(self, cohort_count):
        """Sets the cohort_count of this CohortWindow.


        :param cohort_count: The cohort_count of this CohortWindow.  # noqa: E501
        :type: float
        """

        self._cohort_count = cohort_count

    @property
    def geographic_counts(self):
        """Gets the geographic_counts of this CohortWindow.  # noqa: E501


        :return: The geographic_counts of this CohortWindow.  # noqa: E501
        :rtype: GeographicCounts
        """
        return self._geographic_counts

    @geographic_counts.setter
    def geographic_counts(self, geographic_counts):
        """Sets the geographic_counts of this CohortWindow.


        :param geographic_counts: The geographic_counts of this CohortWindow.  # noqa: E501
        :type: GeographicCounts
        """

        self._geographic_counts = geographic_counts

    @property
    def geographic_queries(self):
        """Gets the geographic_queries of this CohortWindow.  # noqa: E501


        :return: The geographic_queries of this CohortWindow.  # noqa: E501
        :rtype: GeographicQueries
        """
        return self._geographic_queries

    @geographic_queries.setter
    def geographic_queries(self, geographic_queries):
        """Sets the geographic_queries of this CohortWindow.


        :param geographic_queries: The geographic_queries of this CohortWindow.  # noqa: E501
        :type: GeographicQueries
        """

        self._geographic_queries = geographic_queries

    @property
    def dataset_ids(self):
        """Gets the dataset_ids of this CohortWindow.  # noqa: E501


        :return: The dataset_ids of this CohortWindow.  # noqa: E501
        :rtype: list[str]
        """
        return self._dataset_ids

    @dataset_ids.setter
    def dataset_ids(self, dataset_ids):
        """Sets the dataset_ids of this CohortWindow.


        :param dataset_ids: The dataset_ids of this CohortWindow.  # noqa: E501
        :type: list[str]
        """

        self._dataset_ids = dataset_ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CohortWindow, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CohortWindow):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



import codecs
import os.path
from glob import glob

from sphinx.setup_command import BuildDoc

cmdclass = {'build_sphinx': BuildDoc}

from setuptools import setup, find_packages


def readme():
    with open('README.md') as f:
        return f.read()

def read(rel_path):
    here = os.path.abspath(os.path.dirname(__file__))
    with codecs.open(os.path.join(here, rel_path), 'r') as fp:
        return fp.read()

def get_version(rel_path):
    for line in read(rel_path).splitlines():
        if line.startswith('__version__'):
            delim = '"' if '"' in line else "'"
            return line.split(delim)[1]

    raise RuntimeError("Unable to find version string.")

setup_packages = [
    'Cython',
    'pytest-runner'
]

required_packages = [
    'importlib-metadata<4',
    'ipykernel',
    'numpy',
    'pandas',
    'requests',
    'dynaconf',
    'validation_decorators',
    'scikit-learn',
    'logzero',
    'docutils',
    'importlib-metadata<4',
    'packaging'
]

test_packages = [
    'click',
    'freezegun',
]

extras = {
    'testing': {
        'pytest-cov',
        'pytest-pylint',
        'pytest-mock',
        'flake8',
    },
    'docs': {
        'sphinx',
        'sphinx_rtd_theme',
        'sphinxcontrib-apidoc'
    }
}

name = "curia"
version = get_version("src/curia/__init__.py")

setup(
    name=name,
    version=version,
    description="A library for training and using risk & impactability models on Curia",
    packages=find_packages("src"),
    package_dir={
        "": "src",
        # 'curia': 'src/curia',
        'curia.api': 'src/curia/api',
        'swagger_client': 'src/curia/api/swagger_client'
    },
    py_modules=[os.path.splitext(os.path.basename(path))[0] for path in glob("src/*.py")],
    include_package_data=True,
    long_description=readme(),
    long_description_content_type='text/markdown',
    author="Curia.ai",
    url="https://github.com/FoundryAI/curia-python-sdk",
    classifiers=[
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Operating System :: OS Independent"
    ],
    setup_requires=setup_packages,
    install_requires=required_packages,
    tests_require=test_packages,
    extras_require=extras,
    cmdclass=cmdclass,
    # these are optional and override conf.py settings
    command_options={
        'build_sphinx': {
            'project': ('setup.py', name),
            'version': ('setup.py', version),
            'source_dir': ('setup.py', 'doc'),
            'build_dir': ('setup.py', 'doc/_build')
        }
    },
)



import logging
import math

import numpy as np
import pandas as pd
from numpy.random import binomial, multivariate_normal, normal, uniform
from sklearn.model_selection import train_test_split


# pylint: disable=bad-option-value,bad-continuation,too-many-locals,too-many-statements,logging-format-interpolation,logging-fstring-interpolation,consider-using-f-string


def generate_data(
        binary_treatment: bool = True,
        binary_outcome: bool = False,

        n_train: int = 1000,
        n_test: int = 100,

        binary_dim: int = 5,
        uniform_dim: int = 5,
        normal_dim: int = 5,

        n_confounders: int = 2,
        n_features_outcome: int = 3,
        n_features_treatment_effect: int = 3,
        n_features_propensity: int = 3,

        outcome_noise_sd: int = 1,

        missing_data_scaler: float = 0.5,

        treatment_share_scaler: float = 0.05,

        # Random seed
        seed: int = 42) -> object:
    """

    Parameters
    ----------
    binary_treatment: bool :
         (Default value = True)
    binary_outcome: bool :
         (Default value = False)
    n_train: int :
         (Default value = 1000)
    n_test: int :
         (Default value = 100)
    binary_dim: int :
         (Default value = 5)
    uniform_dim: int :
         (Default value = 5)
    normal_dim: int :
         (Default value = 5)
    n_confounders: int :
         (Default value = 2)
    n_features_outcome: int :
         (Default value = 3)
    n_features_treatment_effect: int :
         (Default value = 3)
    n_features_propensity: int :
         (Default value = 3)
    outcome_noise_sd: int :
         (Default value = 1)
    missing_data_scaler: float :
         (Default value = 0.5)
    treatment_share_scaler: float :
         (Default value = 0.05)
    # Random seedseed: int :
         (Default value = 42)

    Returns
    -------

    """

    # Sum train and test together for now
    n_total = n_train + n_test

    # Calculate actual values for the number of the missing features
    n_features_to_drop_outcome_not_counfounders = math.floor(
        (n_features_outcome - n_confounders) * missing_data_scaler)
    n_features_to_drop_treatment_effect_not_counfounders = math.floor(
        (n_features_treatment_effect - n_confounders) * missing_data_scaler)
    n_features_to_drop_confounders = math.floor(
        n_confounders * missing_data_scaler)
    n_features_to_drop_propensity = math.floor(
        n_features_propensity * missing_data_scaler)

    # create empty dataframe
    modeling_df = pd.DataFrame()

    np.random.seed(seed)

    # Generate Age - we will add mean=70 and sd=30 later to avoid high influence of this variable
    modeling_df['age'] = normal(loc=0, scale=1, size=n_total)

    # Generate features with uniform distribution - will multiply to 10 later
    for i in range(0, uniform_dim):
        modeling_df['sdoh_' +
                    str(i)] = np.ceil(uniform(size=n_total) * 10) / 10

    # Generate features with bernoulli distribution
    binary_coefs = uniform(size=binary_dim)
    for i in range(0, binary_dim):
        binary_coef = binary_coefs[i]
        modeling_df['binary_flag_' +
                    str(i)] = binomial(n=1, p=binary_coef, size=n_total)

    # Generate features with normal distribution
    multivariate_df = pd.DataFrame(multivariate_normal(np.zeros(normal_dim),
                                                       np.diag(
                                                           np.ones(normal_dim)),
                                                       n_total),
                                   columns=['vector_' + str(i) for i in range(0, normal_dim)])
    modeling_df = pd.concat([modeling_df, multivariate_df], axis=1)

    # logging.debug shape of the feature set
    logging.debug('Dimentionality of the featureset before dropping any features: {}'.format(
        modeling_df.shape), end='\n\n')

    # Extract name of the features
    features = pd.Series(modeling_df.columns)

    # sample features for the confounders
    confounders_features = features.sample(n_confounders)
    logging.debug(f'confounders_features: {confounders_features.values}')
    # sample features for the outcomes
    outcome_features_not_confounders = features[~features.isin(confounders_features)].sample(
        n_features_outcome - n_confounders)
    outcome_features = pd.concat(
        [outcome_features_not_confounders, confounders_features])
    logging.debug(f'outcome_features: {outcome_features.values}')

    # sample features for the treatment effect
    treatment_effect_features_not_confounders = features[~features.isin(outcome_features)].sample(
        n_features_treatment_effect - n_confounders)
    treatment_effect_features = pd.concat(
        [treatment_effect_features_not_confounders, confounders_features])
    logging.debug(f'treatment_effect_features: {treatment_effect_features.values}')
    # sample features for the propensity score
    propensity_score_features = features.sample(n_features_propensity)
    logging.debug(f'propensity_score_features: {propensity_score_features.values}')

    # Generate coefficients
    beta_outcome = normal(0, 1, n_features_outcome)
    top_outcome_features = pd.DataFrame(
        {'outcome_features': outcome_features, 'beta_coef': np.abs(beta_outcome)}).sort_values(
        by='beta_coef', ascending=False).reset_index(drop=True).head(5)['outcome_features'].values
    logging.debug(f'Top outcome_features by descending importance: {top_outcome_features}')

    # Generate outcomes
    modeling_df['y0'] = np.dot(modeling_df[outcome_features], beta_outcome) + normal(0,
                                                                                     outcome_noise_sd)

    # Generate coefficients
    beta_te = normal(0, 1, n_features_treatment_effect)
    top_treatment_effect = pd.DataFrame({'treatment_effect_features': treatment_effect_features,
                                         'beta_coef': np.abs(beta_te)}).sort_values(by='beta_coef',
                                                                                    ascending=False).reset_index(
        drop=True).head(5)['treatment_effect_features'].values
    logging.debug(f'Top treatment_effect_features by descending importance: {top_treatment_effect}')

    # Generate outcomes
    modeling_df['true_ite'] = np.dot(
        modeling_df[treatment_effect_features], beta_te)

    # Generate coefficients for propensity score
    # Draw coefficients from beta distributions
    beta_propensity_score = normal(0, 1, n_features_propensity)

    top_propensity_score = pd.DataFrame({'propensity_score_features': propensity_score_features,
                                         'beta_coef': np.abs(beta_propensity_score)}).sort_values(
        by='beta_coef',
        ascending=False).reset_index(
        drop=True).head(5)['propensity_score_features'].values
    logging.debug(f'Top propensity_score_features by descending importance: {top_propensity_score}')

    # Generate propensity score and rescale it again from 0 to 1
    modeling_df['true_treatment_propensity'] = np.dot(modeling_df[propensity_score_features],
                                                      beta_propensity_score)

    # Center the distribution first
    modeling_df['true_treatment_propensity'] = modeling_df['true_treatment_propensity'] - \
                                               modeling_df['true_treatment_propensity'].mean()

    # Rescale to -1 to +1
    modeling_df['true_treatment_propensity'] = modeling_df['true_treatment_propensity'] / \
                                               modeling_df['true_treatment_propensity'].abs().max()

    # Rescale to get treatment_share_scaler
    modeling_df['true_treatment_propensity'] = modeling_df['true_treatment_propensity'] * \
                                               min(treatment_share_scaler,
                                                   1 - treatment_share_scaler)

    # Move to the right
    modeling_df['true_treatment_propensity'] = modeling_df['true_treatment_propensity'] + \
                                               treatment_share_scaler

    logging.debug('Average true_treatment_propensity value:{:0.2f}'.format(
        modeling_df['true_treatment_propensity'].mean()))
    logging.debug('Min true_treatment_propensity value:{:0.2f}'.format(
        modeling_df['true_treatment_propensity'].min()))
    logging.debug('Max true_treatment_propensity value:{:0.2f}'.format(
        modeling_df['true_treatment_propensity'].max()), end='\n\n')

    # If binary - use propensity score to generate bernoulli treatment
    # If continuous - just rescale propensity score

    # # Rescale to the needed distribution - shift mean to zero, then shift to all by treatment_share_scaler
    # modeling_df['true_treatment_propensity'] = (
    #     modeling_df['true_treatment_propensity'] - modeling_df['true_treatment_propensity'].mean()) + treatment_share_scaler

    if binary_treatment:
        modeling_df['treatment'] = binomial(n=1, p=modeling_df['true_treatment_propensity'],
                                            size=n_total)
    else:
        modeling_df['treatment'] = modeling_df['true_treatment_propensity']

    logging.debug('Average treatment value:{:0.2f}'.format(
        modeling_df['treatment'].mean()))
    logging.debug('Min treatment value:{:0.2f}'.format(modeling_df['treatment'].min()))
    logging.debug('Max treatment value:{:0.2f}'.format(
        modeling_df['treatment'].max()), end='\n\n')

    modeling_df['y1'] = modeling_df['y0'] + modeling_df['true_ite']
    modeling_df['y'] = modeling_df['y0'] + \
                       modeling_df['true_ite'] * modeling_df['treatment']

    # Rescale from 0 to 1
    y_min = modeling_df[['y', 'y0', 'y1']].min().min()
    y_max = modeling_df[['y', 'y0', 'y1']].max().max()
    scale_factor = 1 / (y_max - y_min)
    modeling_df['y'] = (modeling_df['y'] - y_min) * scale_factor
    modeling_df['y0'] = (modeling_df['y0'] - y_min) * scale_factor
    modeling_df['y1'] = (modeling_df['y1'] - y_min) * scale_factor

    modeling_df['true_ite_rescaled'] = modeling_df['true_ite'] * scale_factor
    modeling_df['true_ite'] = modeling_df['y1'] - \
                              modeling_df['y0']  # modeling_df['true_ite'] * scale_factor

    logging.debug('Average treatment effect value:{:0.2f}'.format(
        modeling_df['true_ite'].mean()))
    logging.debug('Min treatment effect value:{:0.2f}'.format(
        modeling_df['true_ite'].min()))
    logging.debug('Max treatment effect value:{:0.2f}'.format(
        modeling_df['true_ite'].max()), end='\n\n')

    # If binary - rescale to [0,1] and use as probability to generate bernoulli outcome
    if binary_outcome:
        modeling_df['y'] = binomial(n=1, p=modeling_df['y'], size=n_total)

    logging.debug('Average outcome value:{:0.2f}'.format(modeling_df['y'].mean()))
    logging.debug('Min outcome value:{:0.2f}'.format(modeling_df['y'].min()))
    logging.debug('Max outcome value:{:0.2f}'.format(
        modeling_df['y'].max()), end='\n\n')

    # drop temporary variables
    #    del modeling_df['y0']

    # Rescale age feature
    modeling_df['age'] = np.where(modeling_df['age'] * 30 + 70 < 50, 50,
                                  modeling_df['age'] * 30 + 70)

    # Rescale SDOH features
    for i in range(0, uniform_dim):
        modeling_df['sdoh_' + str(i)] = modeling_df['sdoh_' + str(i)] * 10

    # features_to_drop_outcome_not_counfounders
    features_to_drop_outcome_not_counfounders = outcome_features_not_confounders.sample(
        n_features_to_drop_outcome_not_counfounders)
    logging.debug(
        f'n_features_to_drop_outcome_not_counfounders: {n_features_to_drop_outcome_not_counfounders}')
    logging.debug(
        f'features_to_drop_outcome_not_counfounders: {features_to_drop_outcome_not_counfounders.values}')

    # features_to_drop_treatment_effect_not_confounders
    features_to_drop_treatment_effect_not_confounders = treatment_effect_features_not_confounders.sample(
        n_features_to_drop_treatment_effect_not_counfounders)
    logging.debug(
        f'n_features_to_drop_treatment_effect_not_counfounders: {n_features_to_drop_treatment_effect_not_counfounders}')
    logging.debug(
        f'features_to_drop_treatment_effect_not_confounders: {features_to_drop_treatment_effect_not_confounders.values}')

    # features_to_drop_confounders
    features_to_drop_confounders = confounders_features.sample(
        n_features_to_drop_confounders)
    logging.debug(f'n_features_to_drop_confounders: {n_features_to_drop_confounders}')
    logging.debug(f'features_to_drop_confounders: {features_to_drop_confounders.values}')

    # features_to_drop_confounders
    features_to_drop_propensity = propensity_score_features.sample(
        n_features_to_drop_propensity)
    logging.debug(f'n_features_to_drop_propensity: {n_features_to_drop_propensity}')
    logging.debug(f'features_to_drop_propensity: {features_to_drop_propensity.values}')

    # Now drop all those features
    all_features_to_drop = pd.concat([features_to_drop_outcome_not_counfounders,
                                      features_to_drop_treatment_effect_not_confounders,
                                      features_to_drop_confounders,
                                      features_to_drop_propensity]).drop_duplicates()

    for col in all_features_to_drop:
        logging.debug('Dropping {} from the columns'.format([col]))
        assert (col in modeling_df), 'All features to drop should be in the featureset'
        del modeling_df[col]

    # Randomly select train and test
    y = modeling_df['y']
    t = modeling_df['treatment']
    true_ite = modeling_df['true_ite']
    true_treatment_propensity = modeling_df['true_treatment_propensity']
    X = modeling_df.drop(['y', 'y0', 'y1', 'treatment', 'true_ite',
                          'true_treatment_propensity', 'true_ite_rescaled'], axis=1)

    # train_test_split
    logging.debug('Split to train ({} records) and test ({} records)'.format(n_train, n_test))
    X_train, X_test, t_train, t_test, y_train, y_test, true_ite_train, true_ite_test, true_treatment_propensity_train, true_treatment_propensity_test = train_test_split(
        X, t, y, true_ite, true_treatment_propensity, test_size=n_test,
        train_size=n_train, random_state=42)
    return (X_train, X_test, t_train, t_test, y_train, y_test, true_ite_train, true_ite_test,
            true_treatment_propensity_train, true_treatment_propensity_test)



# coding: utf-8

"""
    Curia Platform API

    These are the docs for the curia platform API. To test, generate an authorization token first.  # noqa: E501

    OpenAPI spec version: 1.18.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class CohortFilter(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'dataset_id': 'str',
        'enabled': 'bool',
        'order': 'float',
        'period_definition': 'str',
        'period_preposition': 'str',
        'start_date': 'datetime',
        'end_date': 'datetime',
        'cohort_filter_conditions': 'list[CohortFilterCondition]',
        'type': 'str'
    }

    attribute_map = {
        'dataset_id': 'datasetId',
        'enabled': 'enabled',
        'order': 'order',
        'period_definition': 'periodDefinition',
        'period_preposition': 'periodPreposition',
        'start_date': 'startDate',
        'end_date': 'endDate',
        'cohort_filter_conditions': 'cohortFilterConditions',
        'type': 'type'
    }

    def __init__(self, dataset_id=None, enabled=None, order=None, period_definition=None, period_preposition=None, start_date=None, end_date=None, cohort_filter_conditions=None, type=None):  # noqa: E501
        """CohortFilter - a model defined in Swagger"""  # noqa: E501
        self._dataset_id = None
        self._enabled = None
        self._order = None
        self._period_definition = None
        self._period_preposition = None
        self._start_date = None
        self._end_date = None
        self._cohort_filter_conditions = None
        self._type = None
        self.discriminator = None
        if dataset_id is not None:
            self.dataset_id = dataset_id
        if enabled is not None:
            self.enabled = enabled
        if order is not None:
            self.order = order
        if period_definition is not None:
            self.period_definition = period_definition
        if period_preposition is not None:
            self.period_preposition = period_preposition
        if start_date is not None:
            self.start_date = start_date
        if end_date is not None:
            self.end_date = end_date
        if cohort_filter_conditions is not None:
            self.cohort_filter_conditions = cohort_filter_conditions
        if type is not None:
            self.type = type

    @property
    def dataset_id(self):
        """Gets the dataset_id of this CohortFilter.  # noqa: E501


        :return: The dataset_id of this CohortFilter.  # noqa: E501
        :rtype: str
        """
        return self._dataset_id

    @dataset_id.setter
    def dataset_id(self, dataset_id):
        """Sets the dataset_id of this CohortFilter.


        :param dataset_id: The dataset_id of this CohortFilter.  # noqa: E501
        :type: str
        """

        self._dataset_id = dataset_id

    @property
    def enabled(self):
        """Gets the enabled of this CohortFilter.  # noqa: E501


        :return: The enabled of this CohortFilter.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this CohortFilter.


        :param enabled: The enabled of this CohortFilter.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def order(self):
        """Gets the order of this CohortFilter.  # noqa: E501


        :return: The order of this CohortFilter.  # noqa: E501
        :rtype: float
        """
        return self._order

    @order.setter
    def order(self, order):
        """Sets the order of this CohortFilter.


        :param order: The order of this CohortFilter.  # noqa: E501
        :type: float
        """

        self._order = order

    @property
    def period_definition(self):
        """Gets the period_definition of this CohortFilter.  # noqa: E501


        :return: The period_definition of this CohortFilter.  # noqa: E501
        :rtype: str
        """
        return self._period_definition

    @period_definition.setter
    def period_definition(self, period_definition):
        """Sets the period_definition of this CohortFilter.


        :param period_definition: The period_definition of this CohortFilter.  # noqa: E501
        :type: str
        """

        self._period_definition = period_definition

    @property
    def period_preposition(self):
        """Gets the period_preposition of this CohortFilter.  # noqa: E501


        :return: The period_preposition of this CohortFilter.  # noqa: E501
        :rtype: str
        """
        return self._period_preposition

    @period_preposition.setter
    def period_preposition(self, period_preposition):
        """Sets the period_preposition of this CohortFilter.


        :param period_preposition: The period_preposition of this CohortFilter.  # noqa: E501
        :type: str
        """

        self._period_preposition = period_preposition

    @property
    def start_date(self):
        """Gets the start_date of this CohortFilter.  # noqa: E501


        :return: The start_date of this CohortFilter.  # noqa: E501
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this CohortFilter.


        :param start_date: The start_date of this CohortFilter.  # noqa: E501
        :type: datetime
        """

        self._start_date = start_date

    @property
    def end_date(self):
        """Gets the end_date of this CohortFilter.  # noqa: E501


        :return: The end_date of this CohortFilter.  # noqa: E501
        :rtype: datetime
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this CohortFilter.


        :param end_date: The end_date of this CohortFilter.  # noqa: E501
        :type: datetime
        """

        self._end_date = end_date

    @property
    def cohort_filter_conditions(self):
        """Gets the cohort_filter_conditions of this CohortFilter.  # noqa: E501


        :return: The cohort_filter_conditions of this CohortFilter.  # noqa: E501
        :rtype: list[CohortFilterCondition]
        """
        return self._cohort_filter_conditions

    @cohort_filter_conditions.setter
    def cohort_filter_conditions(self, cohort_filter_conditions):
        """Sets the cohort_filter_conditions of this CohortFilter.


        :param cohort_filter_conditions: The cohort_filter_conditions of this CohortFilter.  # noqa: E501
        :type: list[CohortFilterCondition]
        """

        self._cohort_filter_conditions = cohort_filter_conditions

    @property
    def type(self):
        """Gets the type of this CohortFilter.  # noqa: E501


        :return: The type of this CohortFilter.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this CohortFilter.


        :param type: The type of this CohortFilter.  # noqa: E501
        :type: str
        """

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CohortFilter, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CohortFilter):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
